require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cipher',
  dscmeta_resource_friendly_name: 'Cipher',
  dscmeta_resource_name: 'MSFT_Cipher',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SChannelDsc',
  dscmeta_module_version: '1.4.0',
  docs: 'The DSC Cipher resource type.
         Automatically generated from version 1.4.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_cipher: {
      type: "Enum['AES 128/128', 'AES 256/256', 'DES 56/56', 'NULL', 'RC2 128/128', 'RC2 40/128', 'RC2 56/128', 'RC4 128/128', 'RC4 40/128', 'RC4 56/128', 'RC4 64/128', 'Triple DES 168']",
      desc: 'Specifies the Cipher to configure',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_rebootwhenrequired: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if a reboot will be performed when required (Default: False)',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_state: {
      type: "Optional[Enum['Enabled', 'Disabled', 'Default']]",
      desc: 'Specifies the state of the Cipher',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
