require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_ciphersuites',
  dscmeta_resource_friendly_name: 'CipherSuites',
  dscmeta_resource_name: 'MSFT_CipherSuites',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SChannelDsc',
  dscmeta_module_version: '1.4.0',
  docs: 'The DSC CipherSuites resource type.
         Automatically generated from version 1.4.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_rebootwhenrequired: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if a reboot will be performed when required (Default: False)',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes']",
      desc: 'Required parameter to enforce the resource is only added once',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ciphersuitesorder: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies which Cipher Suites should be configured on the server',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specifies if the specified Cipher Suites should be present or not',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
