require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_protocol',
  dscmeta_resource_friendly_name: 'Protocol',
  dscmeta_resource_name: 'MSFT_Protocol',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SChannelDsc',
  dscmeta_module_version: '1.4.0',
  docs: 'The DSC Protocol resource type.
         Automatically generated from version 1.4.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_protocol: {
      type: "Enum['Multi-Protocol Unified Hello', 'PCT 1.0', 'SSL 2.0', 'SSL 3.0', 'TLS 1.0', 'TLS 1.1', 'TLS 1.2', 'TLS 1.3']",
      desc: 'Specifies the Protocol to configure',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_includeclientside: {
      type: 'Optional[Boolean]',
      desc: 'Specifies to also include Client Side protocols (Default: False)',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_state: {
      type: "Optional[Enum['Enabled', 'Disabled', 'Default']]",
      desc: 'Specifies the state of the specified Protocol',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_rebootwhenrequired: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if a reboot will be performed when required (Default: False)',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
