require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_schannelsettings',
  dscmeta_resource_friendly_name: 'SChannelSettings',
  dscmeta_resource_name: 'MSFT_SChannelSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'SChannelDsc',
  dscmeta_module_version: '1.4.0',
  docs: 'The DSC SChannelSettings resource type.
         Automatically generated from version 1.4.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_enablefipsalgorithmpolicy: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if the FIPS Algorithm Policy is enabled',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_winhttpdefaultsecureprotocols: {
      type: "Optional[Array[Enum['SSL2.0', 'SSL3.0', 'TLS1.0', 'TLS1.1', 'TLS1.2']]]",
      desc: 'Specifies the WinHTTP Default Secure Protocols',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_kerberossupportedencryptiontype: {
      type: "Optional[Array[Enum['DES-CBC-CRC', 'DES-CBC-MD5', 'RC4-HMAC-MD5', 'AES128-HMAC-SHA1', 'AES256-HMAC-SHA1']]]",
      desc: 'Specifies the supported Kerberos Encryption Types',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_rebootwhenrequired: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if a reboot will be performed when required (Default: False)',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_tls12state: {
      type: "Optional[Enum['Enabled', 'Disabled', 'Default']]",
      desc: 'Specifies the state of TLS 1.2 for the .Net Framework 3.5 and 4.*',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_diffiehellmanminclientkeysize: {
      type: "Optional[Enum['1024', '2048', '3072', '4096']]",
      desc: 'Minimum client key size for the Diffie-Hellman key exchange algorithm',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes']",
      desc: "Specifies the resource is a single instance, the value must be 'Yes'",
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_diffiehellmanminserverkeysize: {
      type: "Optional[Enum['1024', '2048', '3072', '4096']]",
      desc: 'Minimum server key size for the Diffie-Hellman key exchange algorithm',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
